@@ -7,8 +7,8 @@
 namespace stan {
   namespace lang {
 
-    row_vector_expr::row_vector_expr() : args_(), has_var_(false),
-                                         row_vector_expr_scope_() { }
+    row_vector_expr::row_vector_expr()
+      : args_(), has_var_(false), row_vector_expr_scope_() { }
 
     row_vector_expr::row_vector_expr(const std::vector<expression>& args)
       : args_(args), has_var_(false), row_vector_expr_scope_() { }
