@@ -3,6 +3,7 @@
 
 #include <stan/lang/ast.hpp>
 #include <string>
+#include <iostream>
 
 namespace stan {
   namespace lang {
@@ -11,18 +12,14 @@ namespace stan {
       return map_.find(name) != map_.end();
     }
 
-    base_var_decl variable_map::get(const std::string& name) const {
+    var_decl variable_map::get(const std::string& name) const {
       if (!exists(name))
         throw std::invalid_argument("variable does not exist");
       return map_.find(name)->second.first;
     }
 
-    base_expr_type variable_map::get_base_type(const std::string& name) const {
-      return get(name).base_type_;
-    }
-
-    size_t variable_map::get_num_dims(const std::string& name) const {
-      return get(name).dims_.size();
+    bare_expr_type variable_map::get_bare_type(const std::string& name) const {
+      return get(name).bare_type_;
     }
 
     scope variable_map::get_scope(const std::string& name) const {
@@ -32,15 +29,18 @@ namespace stan {
     }
 
     void variable_map::add(const std::string& name,
-                           const base_var_decl& base_decl,
+                           const var_decl& decl,
                            const scope& scope_decl) {
-      map_[name] = range_t(base_decl, scope_decl);
+      map_[name] = range_t(decl, scope_decl);
     }
 
     void variable_map::remove(const std::string& name) {
       map_.erase(name);
     }
 
+    size_t variable_map::size() const {
+      return map_.size();
+    }
   }
 }
 #endif
