@@ -1,10 +1,11 @@
 #ifndef STAN_LANG_GRAMMARS_PROGRAM_GRAMMAR_HPP
 #define STAN_LANG_GRAMMARS_PROGRAM_GRAMMAR_HPP
 
+#include <stan/io/program_reader.hpp>
 #include <stan/lang/ast.hpp>
 #include <stan/lang/grammars/whitespace_grammar.hpp>
 #include <stan/lang/grammars/expression_grammar.hpp>
-#include <stan/lang/grammars/var_decls_grammar.hpp>
+#include <stan/lang/grammars/block_var_decls_grammar.hpp>
 #include <stan/lang/grammars/semantic_actions.hpp>
 #include <stan/lang/grammars/statement_grammar.hpp>
 #include <stan/lang/grammars/functions_grammar.hpp>
@@ -24,39 +25,41 @@ namespace stan {
                                    program(),
                                    whitespace_grammar<Iterator> > {
       std::string model_name_;
+      const io::program_reader& reader_;
       variable_map var_map_;
       std::stringstream error_msgs_;
       expression_grammar<Iterator> expression_g;
-      var_decls_grammar<Iterator> var_decls_g;
+      block_var_decls_grammar<Iterator> block_var_decls_g;
       statement_grammar<Iterator> statement_g;
       functions_grammar<Iterator> functions_g;
 
       program_grammar(const std::string& model_name,
+                      const io::program_reader& reader,
                       bool allow_undefined = false);
 
       boost::spirit::qi::rule<Iterator,
                               boost::spirit::qi::locals<scope>,
-                              std::vector<var_decl>(),
+                              std::vector<block_var_decl>(),
                               whitespace_grammar<Iterator> >
       data_var_decls_r;
 
       boost::spirit::qi::rule<Iterator,
                               boost::spirit::qi::locals<scope>,
-                              std::pair<std::vector<var_decl>,
+                              std::pair<std::vector<block_var_decl>,
                                         std::vector<statement> >(),
                               whitespace_grammar<Iterator> >
       derived_data_var_decls_r;
 
       boost::spirit::qi::rule<Iterator,
                               boost::spirit::qi::locals<scope>,
-                              std::pair<std::vector<var_decl>,
+                              std::pair<std::vector<block_var_decl>,
                                         std::vector<statement> >(),
                               whitespace_grammar<Iterator> >
       derived_var_decls_r;
 
       boost::spirit::qi::rule<Iterator,
                               boost::spirit::qi::locals<scope>,
-                              std::pair<std::vector<var_decl>,
+                              std::pair<std::vector<block_var_decl>,
                                         std::vector<statement> >(),
                               whitespace_grammar<Iterator> >
       generated_var_decls_r;
@@ -69,7 +72,7 @@ namespace stan {
 
       boost::spirit::qi::rule<Iterator,
                               boost::spirit::qi::locals<scope>,
-                              std::vector<var_decl>(),
+                              std::vector<block_var_decl>(),
                               whitespace_grammar<Iterator> >
       param_var_decls_r;
 
