@@ -9,17 +9,16 @@
 #include <vector>
 
 namespace stan {
-  namespace math {
+namespace math {
 
-    template<typename T, int R, int C>
-    inline
-    Eigen::Matrix<fvar<T>, C, C>
-    crossprod(const Eigen::Matrix<fvar<T>, R, C>& m) {
-      if (m.rows() == 0)
-        return Eigen::Matrix<fvar<T>, C, C>(0, 0);
-      return multiply(transpose(m), m);
-    }
-
-  }
+template <typename T, int R, int C>
+inline Eigen::Matrix<fvar<T>, C, C> crossprod(
+    const Eigen::Matrix<fvar<T>, R, C>& m) {
+  if (m.rows() == 0)
+    return Eigen::Matrix<fvar<T>, C, C>(0, 0);
+  return multiply(transpose(m), m);
 }
+
+}  // namespace math
+}  // namespace stan
 #endif
