@@ -5,6 +5,7 @@
 #include <stan/math/fwd/scal/fun/value_of_rec.hpp>
 #include <stan/math/prim/scal/err/domain_error.hpp>
 #include <stan/math/prim/scal/fun/gamma_p.hpp>
+#include <stan/math/prim/scal/fun/lgamma.hpp>
 #include <stan/math/prim/scal/fun/grad_reg_lower_inc_gamma.hpp>
 #include <limits>
 
@@ -14,7 +15,6 @@ namespace math {
 template <typename T>
 inline fvar<T> gamma_p(const fvar<T> &x1, const fvar<T> &x2) {
   using boost::math::digamma;
-  using boost::math::lgamma;
   using std::exp;
   using std::fabs;
   using std::log;
@@ -60,7 +60,7 @@ inline fvar<T> gamma_p(double x1, const fvar<T> &x2) {
   if (is_inf(x1))
     return fvar<T>(u, std::numeric_limits<double>::quiet_NaN());
 
-  T der2 = exp(-x2.val_ + (x1 - 1.0) * log(x2.val_) - boost::math::lgamma(x1));
+  T der2 = exp(-x2.val_ + (x1 - 1.0) * log(x2.val_) - lgamma(x1));
 
   return fvar<T>(u, x2.d_ * der2);
 }
