@@ -5,16 +5,14 @@
 #include <stan/math/prim/scal/fun/log1p_exp.hpp>
 
 namespace stan {
-  namespace math {
+namespace math {
 
-    template <typename T>
-    inline
-    fvar<T>
-    log1p_exp(const fvar<T>& x) {
-      using std::exp;
-      return fvar<T>(log1p_exp(x.val_), x.d_ / (1 + exp(-x.val_)));
-    }
-
-  }
+template <typename T>
+inline fvar<T> log1p_exp(const fvar<T>& x) {
+  using std::exp;
+  return fvar<T>(log1p_exp(x.val_), x.d_ / (1 + exp(-x.val_)));
 }
+
+}  // namespace math
+}  // namespace stan
 #endif
