@@ -13,7 +13,7 @@ namespace math {
  * @param[in] x Argument.
  * @return Natural exponential of argument.
  */
-inline double exp(int x) { return std::exp(static_cast<double>(x)); }
+inline double exp(int x) { return std::exp(x); }
 
 }  // namespace math
 }  // namespace stan
