@@ -5,7 +5,7 @@
 #include <stan/math/prim/scal/meta/value_type.hpp>
 
 namespace stan {
-namespace {
+namespace internal {
 template <bool is_vec, typename T, typename T_container>
 struct scalar_type_helper_pre {
   typedef T_container type;
@@ -18,7 +18,7 @@ struct scalar_type_helper_pre<true, T, T_container> {
       typename stan::math::value_type<T>::type,
       typename stan::math::value_type<T_container>::type>::type type;
 };
-}  // namespace
+}  // namespace internal
 
 /**
  * Metaprogram structure to determine the type of first container of
@@ -28,7 +28,7 @@ struct scalar_type_helper_pre<true, T, T_container> {
  */
 template <typename T>
 struct scalar_type_pre {
-  typedef typename scalar_type_helper_pre<
+  typedef typename internal::scalar_type_helper_pre<
       is_vector<typename stan::math::value_type<T>::type>::value,
       typename stan::math::value_type<T>::type, T>::type type;
 };
