@@ -1,8 +1,6 @@
 #ifndef STAN_MATH_REV_MAT_FUN_TRACE_GEN_QUAD_FORM_HPP
 #define STAN_MATH_REV_MAT_FUN_TRACE_GEN_QUAD_FORM_HPP
 
-#include <boost/utility/enable_if.hpp>
-#include <boost/type_traits.hpp>
 #include <stan/math/prim/mat/fun/Eigen.hpp>
 #include <stan/math/prim/mat/fun/typedefs.hpp>
 #include <stan/math/rev/core.hpp>
@@ -12,10 +10,11 @@
 #include <stan/math/prim/mat/fun/trace_gen_quad_form.hpp>
 #include <stan/math/prim/mat/err/check_multiplicable.hpp>
 #include <stan/math/prim/mat/err/check_square.hpp>
+#include <type_traits>
 
 namespace stan {
 namespace math {
-namespace {
+namespace internal {
 template <typename Td, int Rd, int Cd, typename Ta, int Ra, int Ca, typename Tb,
           int Rb, int Cb>
 class trace_gen_quad_form_vari_alloc : public chainable_alloc {
@@ -81,23 +80,23 @@ class trace_gen_quad_form_vari : public vari {
     computeAdjoints(adj_, value_of(impl_->D_), value_of(impl_->A_),
                     value_of(impl_->B_),
                     reinterpret_cast<Eigen::Matrix<var, Rd, Cd>*>(
-                        boost::is_same<Td, var>::value ? (&impl_->D_) : NULL),
+                        std::is_same<Td, var>::value ? (&impl_->D_) : NULL),
                     reinterpret_cast<Eigen::Matrix<var, Ra, Ca>*>(
-                        boost::is_same<Ta, var>::value ? (&impl_->A_) : NULL),
+                        std::is_same<Ta, var>::value ? (&impl_->A_) : NULL),
                     reinterpret_cast<Eigen::Matrix<var, Rb, Cb>*>(
-                        boost::is_same<Tb, var>::value ? (&impl_->B_) : NULL));
+                        std::is_same<Tb, var>::value ? (&impl_->B_) : NULL));
   }
 
   trace_gen_quad_form_vari_alloc<Td, Rd, Cd, Ta, Ra, Ca, Tb, Rb, Cb>* impl_;
 };
-}  // namespace
+}  // namespace internal
 
 template <typename Td, int Rd, int Cd, typename Ta, int Ra, int Ca, typename Tb,
           int Rb, int Cb>
-inline typename boost::enable_if_c<boost::is_same<Td, var>::value
-                                       || boost::is_same<Ta, var>::value
-                                       || boost::is_same<Tb, var>::value,
-                                   var>::type
+inline typename std::enable_if<std::is_same<Td, var>::value
+                                   || std::is_same<Ta, var>::value
+                                   || std::is_same<Tb, var>::value,
+                               var>::type
 trace_gen_quad_form(const Eigen::Matrix<Td, Rd, Cd>& D,
                     const Eigen::Matrix<Ta, Ra, Ca>& A,
                     const Eigen::Matrix<Tb, Rb, Cb>& B) {
@@ -106,12 +105,13 @@ trace_gen_quad_form(const Eigen::Matrix<Td, Rd, Cd>& D,
   check_multiplicable("trace_gen_quad_form", "A", A, "B", B);
   check_multiplicable("trace_gen_quad_form", "B", B, "D", D);
 
-  trace_gen_quad_form_vari_alloc<Td, Rd, Cd, Ta, Ra, Ca, Tb, Rb, Cb>* baseVari
-      = new trace_gen_quad_form_vari_alloc<Td, Rd, Cd, Ta, Ra, Ca, Tb, Rb, Cb>(
-          D, A, B);
+  internal::trace_gen_quad_form_vari_alloc<Td, Rd, Cd, Ta, Ra, Ca, Tb, Rb, Cb>*
+      baseVari
+      = new internal::trace_gen_quad_form_vari_alloc<Td, Rd, Cd, Ta, Ra, Ca, Tb,
+                                                     Rb, Cb>(D, A, B);
 
-  return var(new trace_gen_quad_form_vari<Td, Rd, Cd, Ta, Ra, Ca, Tb, Rb, Cb>(
-      baseVari));
+  return var(new internal::trace_gen_quad_form_vari<Td, Rd, Cd, Ta, Ra, Ca, Tb,
+                                                    Rb, Cb>(baseVari));
 }
 
 }  // namespace math
