@@ -23,8 +23,6 @@
 #include <stan/math/rev/scal/fun/binary_log_loss.hpp>
 #include <stan/math/rev/scal/fun/boost_fpclassify.hpp>
 #include <stan/math/rev/scal/fun/boost_isfinite.hpp>
-#include <stan/math/rev/scal/fun/boost_isinf.hpp>
-#include <stan/math/rev/scal/fun/boost_isnan.hpp>
 #include <stan/math/rev/scal/fun/boost_isnormal.hpp>
 #include <stan/math/rev/scal/fun/calculate_chain.hpp>
 #include <stan/math/rev/scal/fun/cbrt.hpp>
