@@ -7,13 +7,13 @@
 namespace stan {
 namespace math {
 
-namespace {
+namespace internal {
 class cos_vari : public op_v_vari {
  public:
   explicit cos_vari(vari* avi) : op_v_vari(std::cos(avi->val_), avi) {}
   void chain() { avi_->adj_ -= adj_ * std::sin(avi_->val_); }
 };
-}  // namespace
+}  // namespace internal
 
 /**
  * Return the cosine of a radian-scaled variable (cmath).
@@ -42,7 +42,7 @@ class cos_vari : public op_v_vari {
  * @param a Variable for radians of angle.
  * @return Cosine of variable.
  */
-inline var cos(const var& a) { return var(new cos_vari(a.vi_)); }
+inline var cos(const var& a) { return var(new internal::cos_vari(a.vi_)); }
 
 }  // namespace math
 }  // namespace stan
